@@ -1,8 +1,9 @@
 from typing import List
 from typing import Union
 
-from poetry.io import NullIO
-from poetry.packages import Dependency
+from clikit.api.io import IO
+from clikit.io import NullIO
+
 from poetry.packages import Locker
 from poetry.packages import Package
 from poetry.puzzle import Solver
@@ -14,6 +15,7 @@ from poetry.repositories import Pool
 from poetry.repositories import Repository
 from poetry.repositories.installed_repository import InstalledRepository
 from poetry.semver import parse_constraint
+from poetry.utils.extras import get_extra_package_names
 from poetry.utils.helpers import canonicalize_name
 
 from .base_installer import BaseInstaller
@@ -23,7 +25,7 @@ from .pip_installer import PipInstaller
 class Installer:
     def __init__(
         self,
-        io,
+        io,  # type: IO
         env,
         package,  # type: Package
         locker,  # type: Locker
@@ -41,7 +43,6 @@ class Installer:
         self._verbose = False
         self._write_lock = True
         self._dev_mode = True
-        self._develop = []
         self._execute_operations = True
         self._lock = False
 
@@ -98,11 +99,6 @@ class Installer:
     def is_dev_mode(self):  # type: () -> bool
         return self._dev_mode
 
-    def develop(self, packages):  # type: (dict) -> Installer
-        self._develop = [canonicalize_name(p) for p in packages]
-
-        return self
-
     def update(self, update=True):  # type: (bool) -> Installer
         self._update = update
 
@@ -153,7 +149,7 @@ class Installer:
                 if extra not in self._package.extras:
                     raise ValueError("Extra [{}] is not specified.".format(extra))
 
-            self._io.writeln("<info>Updating dependencies</>")
+            self._io.write_line("<info>Updating dependencies</>")
             solver = Solver(
                 self._package,
                 self._pool,
@@ -164,12 +160,12 @@ class Installer:
 
             ops = solver.solve(use_latest=self._whitelist)
         else:
-            self._io.writeln("<info>Installing dependencies from lock file</>")
+            self._io.write_line("<info>Installing dependencies from lock file</>")
 
             locked_repository = self._locker.locked_repository(True)
 
             if not self._locker.is_fresh():
-                self._io.writeln(
+                self._io.write_line(
                     "<warning>"
                     "Warning: The lock file is not up to date with "
                     "the latest changes in pyproject.toml. "
@@ -205,7 +201,7 @@ class Installer:
             ".".join([str(i) for i in self._env.version_info[:3]])
         ):
             # We resolve again by only using the lock file
-            pool = Pool()
+            pool = Pool(ignore_repository_names=True)
 
             # Making a new repo containing the packages
             # newly resolved and the ones from the current lock file
@@ -233,12 +229,12 @@ class Installer:
         # or optional and not requested, are dropped
         self._filter_operations(ops, local_repo)
 
-        self._io.new_line()
+        self._io.write_line("")
 
         # Execute operations
         actual_ops = [op for op in ops if not op.skipped]
         if not actual_ops and (self._execute_operations or self._dry_run):
-            self._io.writeln("Nothing to install or update")
+            self._io.write_line("No dependencies to install or update")
 
         if actual_ops and (self._execute_operations or self._dry_run):
             installs = []
@@ -266,8 +262,8 @@ class Installer:
                 elif op.job_type == "uninstall":
                     uninstalls.append(op.package.pretty_name)
 
-            self._io.new_line()
-            self._io.writeln(
+            self._io.write_line("")
+            self._io.write_line(
                 "Package operations: "
                 "<info>{}</> install{}, "
                 "<info>{}</> update{}, "
@@ -285,7 +281,7 @@ class Installer:
                 )
             )
 
-        self._io.writeln("")
+        self._io.write_line("")
         for op in ops:
             self._execute(op)
 
@@ -294,8 +290,8 @@ class Installer:
             updated_lock = self._locker.set_lock_data(self._package, repo.packages)
 
             if updated_lock:
-                self._io.writeln("")
-                self._io.writeln("<info>Writing lock file</>")
+                self._io.write_line("")
+                self._io.write_line("<info>Writing lock file</>")
 
     def _execute(self, operation):  # type: (Operation) -> None
         """
@@ -308,8 +304,8 @@ class Installer:
     def _execute_install(self, operation):  # type: (Install) -> None
         if operation.skipped:
             if self.is_verbose() and (self._execute_operations or self.is_dry_run()):
-                self._io.writeln(
-                    "  - Skipping <info>{}</> (<comment>{}</>) {}".format(
+                self._io.write_line(
+                    "  - Skipping <c1>{}</c1> (<b>{}</b>) {}".format(
                         operation.package.pretty_name,
                         operation.package.full_pretty_version,
                         operation.skip_reason,
@@ -319,8 +315,8 @@ class Installer:
             return
 
         if self._execute_operations or self.is_dry_run():
-            self._io.writeln(
-                "  - Installing <info>{}</> (<comment>{}</>)".format(
+            self._io.write_line(
+                "  - Installing <c1>{}</c1> (<b>{}</b>)".format(
                     operation.package.pretty_name, operation.package.full_pretty_version
                 )
             )
@@ -336,8 +332,8 @@ class Installer:
 
         if operation.skipped:
             if self.is_verbose() and (self._execute_operations or self.is_dry_run()):
-                self._io.writeln(
-                    "  - Skipping <info>{}</> (<comment>{}</>) {}".format(
+                self._io.write_line(
+                    "  - Skipping <c1>{}</c1> (<b>{}</b>) {}".format(
                         target.pretty_name,
                         target.full_pretty_version,
                         operation.skip_reason,
@@ -347,8 +343,8 @@ class Installer:
             return
 
         if self._execute_operations or self.is_dry_run():
-            self._io.writeln(
-                "  - Updating <info>{}</> (<comment>{}</> -> <comment>{}</>)".format(
+            self._io.write_line(
+                "  - Updating <c1>{}</c1> (<b>{}</b> -> <b>{}</b>)".format(
                     target.pretty_name,
                     source.full_pretty_version,
                     target.full_pretty_version,
@@ -363,8 +359,8 @@ class Installer:
     def _execute_uninstall(self, operation):  # type: (Uninstall) -> None
         if operation.skipped:
             if self.is_verbose() and (self._execute_operations or self.is_dry_run()):
-                self._io.writeln(
-                    "  - Not removing <info>{}</> (<comment>{}</>) {}".format(
+                self._io.write_line(
+                    "  - Not removing <c1>{}</c1> (<b>{}</b>) {}".format(
                         operation.package.pretty_name,
                         operation.package.full_pretty_version,
                         operation.skip_reason,
@@ -374,8 +370,8 @@ class Installer:
             return
 
         if self._execute_operations or self.is_dry_run():
-            self._io.writeln(
-                "  - Removing <info>{}</> (<comment>{}</>)".format(
+            self._io.write_line(
+                "  - Removing <c1>{}</c1> (<b>{}</b>)".format(
                     operation.package.pretty_name, operation.package.full_pretty_version
                 )
             )
@@ -403,7 +399,7 @@ class Installer:
         installed_repo = self._installed_repository
         ops = []
 
-        extra_packages = [p.name for p in self._get_extra_packages(locked_repository)]
+        extra_packages = self._get_extra_packages(locked_repository)
         for locked in locked_repository.packages:
             is_installed = False
             for installed in installed_repo.packages:
@@ -433,7 +429,7 @@ class Installer:
     def _filter_operations(
         self, ops, repo
     ):  # type: (List[Operation], Repository) -> None
-        extra_packages = [p.name for p in self._get_extra_packages(repo)]
+        extra_packages = self._get_extra_packages(repo)
         for op in ops:
             if isinstance(op, Update):
                 package = op.target_package
@@ -443,11 +439,6 @@ class Installer:
             if op.job_type == "uninstall":
                 continue
 
-            if package.name in self._develop and package.source_type == "directory":
-                package.develop = True
-                if op.skipped:
-                    op.unskip()
-
             current_python = parse_constraint(
                 ".".join(str(v) for v in self._env.version_info[:3])
             )
@@ -477,9 +468,9 @@ class Installer:
             if package.category == "dev" and not self.is_dev_mode():
                 op.skip("Dev dependencies not requested")
 
-    def _get_extra_packages(self, repo):
+    def _get_extra_packages(self, repo):  # type: (Repository) -> List[str]
         """
-        Returns all packages required by extras.
+        Returns all package names required by extras.
 
         Maybe we just let the solver handle it?
         """
@@ -488,29 +479,10 @@ class Installer:
         else:
             extras = self._locker.lock_data.get("extras", {})
 
-        extra_packages = []
-        for extra_name, packages in extras.items():
-            if extra_name not in self._extras:
-                continue
-
-            extra_packages += [Dependency(p, "*") for p in packages]
-
-        def _extra_packages(packages):
-            pkgs = []
-            for package in packages:
-                for pkg in repo.packages:
-                    if pkg.name == package.name:
-                        pkgs.append(package)
-                        pkgs += _extra_packages(pkg.requires)
-
-                        break
-
-            return pkgs
-
-        return _extra_packages(extra_packages)
+        return list(get_extra_package_names(repo.packages, extras, self._extras))
 
     def _get_installer(self):  # type: () -> BaseInstaller
-        return PipInstaller(self._env, self._io)
+        return PipInstaller(self._env, self._io, self._pool)
 
     def _get_installed(self):  # type: () -> InstalledRepository
         return InstalledRepository.load(self._env)
