@@ -220,8 +220,8 @@ class LegacyRepository(PyPiRepository):
 
         return "{scheme}://{username}:{password}@{netloc}{path}".format(
             scheme=parsed.scheme,
-            username=quote(self._auth.auth.username),
-            password=quote(self._auth.auth.password),
+            username=quote(self._auth.auth.username, safe=""),
+            password=quote(self._auth.auth.password, safe=""),
             netloc=parsed.netloc,
             path=parsed.path,
         )
