@@ -8,11 +8,6 @@ from contextlib import contextmanager
 from typing import List
 from typing import Optional
 
-from keyring import delete_password
-from keyring import get_password
-from keyring import set_password
-from keyring.errors import KeyringError
-
 from poetry.config.config import Config
 from poetry.utils._compat import Path
 from poetry.version import Version
@@ -95,53 +90,6 @@ def parse_requires(requires):  # type: (str) -> List[str]
     return requires_dist
 
 
-def keyring_service_name(repository_name):  # type: (str) -> str
-    return "{}-{}".format("poetry-repository", repository_name)
-
-
-def keyring_repository_password_get(
-    repository_name, username
-):  # type: (str, str) -> Optional[str]
-    try:
-        return get_password(keyring_service_name(repository_name), username)
-    except (RuntimeError, KeyringError):
-        return None
-
-
-def keyring_repository_password_set(
-    repository_name, username, password
-):  # type: (str, str, str) -> None
-    try:
-        set_password(keyring_service_name(repository_name), username, password)
-    except (RuntimeError, KeyringError):
-        raise RuntimeError("Failed to store password in keyring")
-
-
-def keyring_repository_password_del(
-    config, repository_name
-):  # type: (Config, str) -> None
-    try:
-        repo_auth = config.get("http-basic.{}".format(repository_name))
-        if repo_auth and "username" in repo_auth:
-            delete_password(
-                keyring_service_name(repository_name), repo_auth["username"]
-            )
-    except (RuntimeError, KeyringError):
-        pass
-
-
-def get_http_basic_auth(
-    config, repository_name
-):  # type: (Config, str) -> Optional[tuple]
-    repo_auth = config.get("http-basic.{}".format(repository_name))
-    if repo_auth:
-        username, password = repo_auth["username"], repo_auth.get("password")
-        if password is None:
-            password = keyring_repository_password_get(repository_name, username)
-        return username, password
-    return None
-
-
 def get_cert(config, repository_name):  # type: (Config, str) -> Optional[Path]
     cert = config.get("certificates.{}.cert".format(repository_name))
     if cert:
@@ -159,11 +107,17 @@ def get_client_cert(config, repository_name):  # type: (Config, str) -> Optional
 
 
 def _on_rm_error(func, path, exc_info):
+    if not os.path.exists(path):
+        return
+
     os.chmod(path, stat.S_IWRITE)
     func(path)
 
 
 def safe_rmtree(path):
+    if Path(path).is_symlink():
+        return os.unlink(str(path))
+
     shutil.rmtree(path, onerror=_on_rm_error)
 
 
